Crate glaciers

Modules

abi_reader
Module for reading and processing EVM ABIs for Glaciers.
configger
Module for configuration management for the Glaciers.
decoder
Module for the high level processing and decoding blockchain data.
log_decoder
Log decoder module have the functions that are specific to decode logs.
matcher
Matching module for associating logs and traces with ABI item signatures.
miscellaneous
Miscellaneous functions for the Glaciers.
trace_decoder
Trace decoder module have the functions that are specific to decode traces.
utils
Utility functions for the Glaciers.